Agents API
==========

This section documents the core Agent classes, including the main Agent class, agent composition tools, and agent team functionality.

.. autosummary::
   :toctree: _autosummary
   :recursive:
   
   agentle.agents
   agentle.agents.agent
   agentle.agents.agent_pipeline
   agentle.agents.agent_team
   agentle.agents.context
   agentle.agents.agent_config
   agentle.agents.agent_input
   agentle.agents.agent_run_output
   agentle.agents.knowledge
   agentle.agents.a2a

Agent
-----

.. automodule:: agentle.agents.agent
   :members:
   :undoc-members:
   :show-inheritance:

Agent Pipeline
-------------

.. automodule:: agentle.agents.agent_pipeline
   :members:
   :undoc-members:
   :show-inheritance:

Agent Team
---------

.. automodule:: agentle.agents.agent_team
   :members:
   :undoc-members:
   :show-inheritance: